summaryrefslogtreecommitdiff
path: root/include/configs/iot_devkit.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/configs/iot_devkit.h')
-rw-r--r--include/configs/iot_devkit.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/configs/iot_devkit.h b/include/configs/iot_devkit.h
index a2e50c3b8d..5a769e0787 100644
--- a/include/configs/iot_devkit.h
+++ b/include/configs/iot_devkit.h
@@ -32,12 +32,12 @@
* : :
* : Specified explicitly by CONFIG_CUSTOM_SYS_INIT_SP_ADDR
* :
* Specified explicitly by CONFIG_SYS_SDRAM_BASE
*
* NOTES:
* - Stack starts from CONFIG_CUSTOM_SYS_INIT_SP_ADDR and grows down,
* i.e. towards CONFIG_SYS_SDRAM_BASE but nothing stops it from crossing
* that CONFIG_SYS_SDRAM_BASE in which case data won't be really saved on
* stack any longer and values popped from stack will contain garbage
* leading to unexpected behavior, typically but not limited to:
* - "Returning" back to bogus caller function
@@ -50,16 +50,16 @@
#define DCCM_BASE 0x80000000
#define DCCM_SIZE SZ_128K
-#define CONFIG_SYS_SDRAM_BASE DCCM_BASE
-#define CONFIG_SYS_SDRAM_SIZE DCCM_SIZE
+#define CFG_SYS_SDRAM_BASE DCCM_BASE
+#define CFG_SYS_SDRAM_SIZE DCCM_SIZE
#define ROM_BASE CONFIG_SYS_MONITOR_BASE
#define ROM_SIZE SZ_256K
#define RAM_DATA_BASE SYS_INIT_SP_ADDR
-#define RAM_DATA_SIZE CONFIG_SYS_SDRAM_SIZE - \
+#define RAM_DATA_SIZE CFG_SYS_SDRAM_SIZE - \
(SYS_INIT_SP_ADDR - \
- CONFIG_SYS_SDRAM_BASE) - \
+ CFG_SYS_SDRAM_BASE) - \
CONFIG_SYS_MALLOC_LEN - \
CONFIG_ENV_SIZE
#endif /* _CONFIG_IOT_DEVKIT_H_ */
@@ -32,12 +32,12 @@
* : Specified explicitly by CONFIG_CUSTOM_SYS_INIT_SP_ADDR
* :
- * Specified explicitly by CONFIG_SYS_SDRAM_BASE
+ * Specified explicitly by CFG_SYS_SDRAM_BASE
*
* NOTES:
@@ -32,12 +32,12 @@
* NOTES:
* - Stack starts from CONFIG_CUSTOM_SYS_INIT_SP_ADDR and grows down,
- * i.e. towards CONFIG_SYS_SDRAM_BASE but nothing stops it from crossing
- * that CONFIG_SYS_SDRAM_BASE in which case data won't be really saved on
+ * i.e. towards CFG_SYS_SDRAM_BASE but nothing stops it from crossing
+ * that CFG_SYS_SDRAM_BASE in which case data won't be really saved on
* stack any longer and values popped from stack will contain garbage
* leading to unexpected behavior, typically but not limited to: